@@ -1,6 +1,13 @@
+import logging
 from learning_loop_node.tests import test_helper
+from learning_loop_node.loop import loop
 import pytest
 import shutil
+import asyncio
+import icecream
+
+icecream.install()
+logging.basicConfig(level=logging.DEBUG)
 
 
 @pytest.fixture()
@@ -14,8 +21,16 @@ def create_project():
     test_helper.LiveServerSession().delete(f"/api/zauberzeug/projects/pytest?keep_images=true")
 
 
+@pytest.fixture(scope='function')
+def data_folder():
+    path = '/tmp/learning_loop_lib_data'
+    shutil.rmtree(path, ignore_errors=True)
+    yield path
+    shutil.rmtree(path, ignore_errors=True)
+
+
 @pytest.fixture(autouse=True, scope='function')
-def cleanup_data_folder():
-    shutil.rmtree('../data', ignore_errors=True)
+def loop_session():
+    loop.session = None
     yield
-    shutil.rmtree('../data', ignore_errors=True)
+    loop.session = None
